import time

__version__ = "0.6.1"
__author__ = "Lukas Hedegaard"
__author_email__ = "lukasxhedegaard@gmail.com"
__license__ = "Apache-2.0"
__copyright__ = f'Copyright (c) 2020-{time.strftime("%Y")}, {__author__}'
__homepage__ = "https://github.com/LukasHedegaard/ride"
__docs__ = "Training wheels, side rails, and helicopter parent for your Deep Learning projects using Pytorch"
